<div dir="rtl">

# احراز هویت کاربران

با استفاده از این پکیج می توانید کاربران خود را احراز هویت کنید و از سیستم مدیریت کاربران پلتفرم پاد استفاده نمایید

# نصب

برای نصب کافیست دستور زیر را اجرا کنید

```
pip install pod-sso
```

# نمونه کد
نمونه کد ها و مثال هایی از تمام متدهای این پکیج را می توانید 
[اینجا](examples)
پیدا کنید.

</div>